# Generated by Django 4.1.3 on 2023-05-02 15:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('organizations', '0008_alter_organization_networks'),
    ]

    operations = [
        migrations.AddField(
            model_name='issuer',
            name='name',
            field=models.CharField(blank=True, max_length=2500),
        ),
    ]
