# Generated by Django 4.1.3 on 2023-01-30 10:04

from django.db import migrations, models
import django.db.models.deletion
import multiselectfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ("organizations", "0005_subject_alter_organization_networks_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="organization",
            name="networks",
            field=multiselectfield.db.fields.MultiSelectField(
                choices=[
                    ("AlastriaDefaultName", "Alastria"),
                    ("LacchainDefaultName", "Lacchain"),
                ],
                max_length=1000,
            ),
        ),
        migrations.CreateModel(
            name="OrganizationOnboardingNotification",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("sended_at", models.DateTimeField()),
                (
                    "operator",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="organizations.userproxy",
                    ),
                ),
                (
                    "organization",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="organizations.organization",
                    ),
                ),
            ],
        ),
    ]
