# Generated by Django 4.1.3 on 2023-01-27 07:31

from django.db import migrations, models
import django.db.models.deletion
import multiselectfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ("organizations", "0004_alter_organization_email_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="Subject",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "email",
                    models.EmailField(
                        blank=True, max_length=200, null=True, verbose_name="Email"
                    ),
                ),
                ("givenName", models.CharField(blank=True, max_length=255)),
                ("familyName", models.CharField(blank=True, max_length=255)),
                ("birthDate", models.DateField(blank=True, null=True)),
                (
                    "intermediary",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="organizations.intermediary",
                    ),
                ),
            ],
            options={
                "verbose_name": "Subject",
                "verbose_name_plural": "Subjects",
            },
        ),
        migrations.AlterField(
            model_name="organization",
            name="networks",
            field=multiselectfield.db.fields.MultiSelectField(
                choices=[("AlastriaDefaultName", "Alastria")], max_length=1000
            ),
        ),
        migrations.AlterField(
            model_name="organization",
            name="operators",
            field=models.ManyToManyField(blank=True, to="organizations.userproxy"),
        ),
        migrations.CreateModel(
            name="SubjectDID",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("network_name", models.CharField(max_length=2500)),
                ("did", models.CharField(max_length=255)),
                (
                    "subject",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="organizations.subject",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="OperatorDID",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("network_name", models.CharField(max_length=2500)),
                ("did", models.CharField(max_length=255)),
                (
                    "operator",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="organizations.userproxy",
                    ),
                ),
            ],
        ),
    ]
