# Generated by Django 4.1.3 on 2023-01-24 10:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("organizations", "0003_alter_organization_networks"),
    ]

    operations = [
        migrations.AlterField(
            model_name="organization",
            name="email",
            field=models.EmailField(blank=True, max_length=254, null=True),
        ),
        migrations.AlterField(
            model_name="organization",
            name="operators",
            field=models.ManyToManyField(
                null=True, to="organizations.userproxy"
            ),
        ),
        migrations.AlterField(
            model_name="organization",
            name="phone",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
