# Generated by Django 4.1.3 on 2023-03-15 15:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('organizations', '0006_alter_organization_networks_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='issuer',
            name='active',
            field=models.BooleanField(default=False),
        ),
    ]
