# Generated by Django 4.1.3 on 2023-04-27 13:44

from django.db import migrations
import multiselectfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('organizations', '0007_alter_issuer_active'),
    ]

    operations = [
        migrations.AlterField(
            model_name='organization',
            name='networks',
            field=multiselectfield.db.fields.MultiSelectField(choices=[('AlastriaDefaultName', 'Alastria'), ('LacchainDefaultName', 'Lacchain'), ('EbsiDefaultName', 'Ebsi')], max_length=1000),
        ),
    ]
